Module: Google::Cloud::AIPlatform

Defined in:
lib/google/cloud/ai_platform.rb,
lib/google/cloud/ai_platform/version.rb

Constant Summary collapse

VERSION =
"1.1.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.ai_platform| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-ai_platform library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
    * `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
    * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
    * `:retry_codes` (*type:* `Array<String>`) -
    The error codes that should trigger a retry.
    

Yields:

Returns:

  • (::Google::Cloud::Config) —

    The default configuration used by this library



747
748
749
750
751
# File 'lib/google/cloud/ai_platform.rb', line 747

def self.configure
  yield ::Google::Cloud.configure.ai_platform if block_given?

  ::Google::Cloud.configure.ai_platform
end

.dataset_service(version: :v1, &block) ⇒ ::Object

Create a new client object for DatasetService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::DatasetService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DatasetService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About DatasetService

The service that manages Vertex AI Dataset and its child resources.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



66
67
68
69
70
71
72
73
74
75
# File 'lib/google/cloud/ai_platform.rb', line 66

def self.dataset_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:DatasetService)
  service_module.const_get(:Client).new(&block)
end

.endpoint_service(version: :v1, &block) ⇒ ::Object

Create a new client object for EndpointService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::EndpointService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the EndpointService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About EndpointService

A service for managing Vertex AI's Endpoints.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



96
97
98
99
100
101
102
103
104
105
# File 'lib/google/cloud/ai_platform.rb', line 96

def self.endpoint_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:EndpointService)
  service_module.const_get(:Client).new(&block)
end

.feature_online_store_admin_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeatureOnlineStoreAdminService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeatureOnlineStoreAdminService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeatureOnlineStoreAdminService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeatureOnlineStoreAdminService

The service that handles CRUD and List for resources for FeatureOnlineStore.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



127
128
129
130
131
132
133
134
135
136
# File 'lib/google/cloud/ai_platform.rb', line 127

def self.feature_online_store_admin_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeatureOnlineStoreAdminService)
  service_module.const_get(:Client).new(&block)
end

.feature_online_store_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeatureOnlineStoreService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeatureOnlineStoreService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeatureOnlineStoreService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



183
184
185
186
187
188
189
190
191
192
# File 'lib/google/cloud/ai_platform.rb', line 183

def self.feature_online_store_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeatureOnlineStoreService)
  service_module.const_get(:Client).new(&block)
end

.feature_registry_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeatureRegistryService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeatureRegistryService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeatureRegistryService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeatureRegistryService

The service that handles CRUD and List for resources for FeatureRegistry.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



244
245
246
247
248
249
250
251
252
253
# File 'lib/google/cloud/ai_platform.rb', line 244

def self.feature_registry_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeatureRegistryService)
  service_module.const_get(:Client).new(&block)
end

.featurestore_online_serving_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeaturestoreOnlineServingService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeaturestoreOnlineServingService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeaturestoreOnlineServingService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeaturestoreOnlineServingService

A service for serving online feature values.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



157
158
159
160
161
162
163
164
165
166
# File 'lib/google/cloud/ai_platform.rb', line 157

def self.featurestore_online_serving_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeaturestoreOnlineServingService)
  service_module.const_get(:Client).new(&block)
end

.featurestore_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeaturestoreService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeaturestoreService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeaturestoreService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeaturestoreService

The service that handles CRUD and List for resources for Featurestore.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



213
214
215
216
217
218
219
220
221
222
# File 'lib/google/cloud/ai_platform.rb', line 213

def self.featurestore_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeaturestoreService)
  service_module.const_get(:Client).new(&block)
end

.index_endpoint_service(version: :v1, &block) ⇒ ::Object

Create a new client object for IndexEndpointService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::IndexEndpointService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the IndexEndpointService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About IndexEndpointService

A service for managing Vertex AI's IndexEndpoints.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



274
275
276
277
278
279
280
281
282
283
# File 'lib/google/cloud/ai_platform.rb', line 274

def self.index_endpoint_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:IndexEndpointService)
  service_module.const_get(:Client).new(&block)
end

.index_service(version: :v1, &block) ⇒ ::Object

Create a new client object for IndexService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::IndexService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the IndexService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About IndexService

A service for creating and managing Vertex AI's Index resources.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



304
305
306
307
308
309
310
311
312
313
# File 'lib/google/cloud/ai_platform.rb', line 304

def self.index_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:IndexService)
  service_module.const_get(:Client).new(&block)
end

.job_service(version: :v1, &block) ⇒ ::Object

Create a new client object for JobService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::JobService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the JobService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About JobService

A service for creating and managing Vertex AI's jobs.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



334
335
336
337
338
339
340
341
342
343
# File 'lib/google/cloud/ai_platform.rb', line 334

def self.job_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:JobService)
  service_module.const_get(:Client).new(&block)
end

.llm_utility_service(version: :v1, &block) ⇒ ::Object

Create a new client object for LlmUtilityService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::LlmUtilityService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the LlmUtilityService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About LlmUtilityService

Service for LLM related utility functions.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



394
395
396
397
398
399
400
401
402
403
# File 'lib/google/cloud/ai_platform.rb', line 394

def self.llm_utility_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:LlmUtilityService)
  service_module.const_get(:Client).new(&block)
end

.match_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MatchService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MatchService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MatchService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MatchService

MatchService is a Google managed service for efficient vector similarity search at scale.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



425
426
427
428
429
430
431
432
433
434
# File 'lib/google/cloud/ai_platform.rb', line 425

def self.match_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MatchService)
  service_module.const_get(:Client).new(&block)
end

.metadata_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MetadataService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MetadataService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MetadataService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MetadataService

Service for reading and writing metadata entries.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



455
456
457
458
459
460
461
462
463
464
# File 'lib/google/cloud/ai_platform.rb', line 455

def self. version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MetadataService)
  service_module.const_get(:Client).new(&block)
end

.migration_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MigrationService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MigrationService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MigrationService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MigrationService

A service that migrates resources from automl.googleapis.com, datalabeling.googleapis.com and ml.googleapis.com to Vertex AI.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



486
487
488
489
490
491
492
493
494
495
# File 'lib/google/cloud/ai_platform.rb', line 486

def self.migration_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MigrationService)
  service_module.const_get(:Client).new(&block)
end

.model_garden_service(version: :v1, &block) ⇒ ::Object

Create a new client object for ModelGardenService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::ModelGardenService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ModelGardenService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About ModelGardenService

The interface of Model Garden Service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



546
547
548
549
550
551
552
553
554
555
# File 'lib/google/cloud/ai_platform.rb', line 546

def self.model_garden_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:ModelGardenService)
  service_module.const_get(:Client).new(&block)
end

.model_service(version: :v1, &block) ⇒ ::Object

Create a new client object for ModelService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::ModelService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ModelService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About ModelService

A service for managing Vertex AI's machine learning Models.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



516
517
518
519
520
521
522
523
524
525
# File 'lib/google/cloud/ai_platform.rb', line 516

def self.model_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:ModelService)
  service_module.const_get(:Client).new(&block)
end

.pipeline_service(version: :v1, &block) ⇒ ::Object

Create a new client object for PipelineService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::PipelineService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PipelineService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About PipelineService

A service for creating and managing Vertex AI's pipelines. This includes both TrainingPipeline resources (used for AutoML and custom training) and PipelineJob resources (used for Vertex AI Pipelines).

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



578
579
580
581
582
583
584
585
586
587
# File 'lib/google/cloud/ai_platform.rb', line 578

def self.pipeline_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:PipelineService)
  service_module.const_get(:Client).new(&block)
end

.prediction_service(version: :v1, &block) ⇒ ::Object

Create a new client object for PredictionService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::PredictionService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PredictionService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About PredictionService

A service for online predictions and explanations.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



364
365
366
367
368
369
370
371
372
373
# File 'lib/google/cloud/ai_platform.rb', line 364

def self.prediction_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:PredictionService)
  service_module.const_get(:Client).new(&block)
end

.schedule_service(version: :v1, &block) ⇒ ::Object

Create a new client object for ScheduleService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::ScheduleService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ScheduleService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About ScheduleService

A service for creating and managing Vertex AI's Schedule resources to periodically launch shceudled runs to make API calls.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



609
610
611
612
613
614
615
616
617
618
# File 'lib/google/cloud/ai_platform.rb', line 609

def self.schedule_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:ScheduleService)
  service_module.const_get(:Client).new(&block)
end

.specialist_pool_service(version: :v1, &block) ⇒ ::Object

Create a new client object for SpecialistPoolService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::SpecialistPoolService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the SpecialistPoolService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About SpecialistPoolService

A service for creating and managing Customer SpecialistPools. When customers start Data Labeling jobs, they can reuse/create Specialist Pools to bring their own Specialists to label the data. Customers can add/remove Managers for the Specialist Pool on Cloud console, then Managers will get email notifications to manage Specialists and tasks on CrowdCompute console.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



644
645
646
647
648
649
650
651
652
653
# File 'lib/google/cloud/ai_platform.rb', line 644

def self.specialist_pool_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:SpecialistPoolService)
  service_module.const_get(:Client).new(&block)
end

.tensorboard_service(version: :v1, &block) ⇒ ::Object

Create a new client object for TensorboardService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::TensorboardService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the TensorboardService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About TensorboardService

TensorboardService

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



674
675
676
677
678
679
680
681
682
683
# File 'lib/google/cloud/ai_platform.rb', line 674

def self.tensorboard_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:TensorboardService)
  service_module.const_get(:Client).new(&block)
end

.vizier_service(version: :v1, &block) ⇒ ::Object

Create a new client object for VizierService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::VizierService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the VizierService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About VizierService

Vertex AI Vizier API.

Vertex AI Vizier is a service to solve blackbox optimization problems, such as tuning machine learning hyperparameters and searching over deep learning architectures.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



708
709
710
711
712
713
714
715
716
717
# File 'lib/google/cloud/ai_platform.rb', line 708

def self.vizier_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:VizierService)
  service_module.const_get(:Client).new(&block)
end