Module: Google::Cloud::AIPlatform

Defined in:
lib/google/cloud/ai_platform.rb,
lib/google/cloud/ai_platform/version.rb

Constant Summary collapse

VERSION =
"0.3.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.ai_platform| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-ai_platform library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
    * `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
    * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
    * `:retry_codes` (*type:* `Array<String>`) -
    The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config) —

    The default configuration used by this library



599
600
601
602
603
# File 'lib/google/cloud/ai_platform.rb', line 599

def self.configure
  yield ::Google::Cloud.configure.ai_platform if block_given?

  ::Google::Cloud.configure.ai_platform
end

.dataset_service(version: :v1, &block) ⇒ ::Object

Create a new client object for DatasetService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::DatasetService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DatasetService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About DatasetService

The service that handles the CRUD of Vertex AI Dataset and its child resources.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



67
68
69
70
71
72
73
74
75
76
# File 'lib/google/cloud/ai_platform.rb', line 67

def self.dataset_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:DatasetService)
  service_module.const_get(:Client).new(&block)
end

.endpoint_service(version: :v1, &block) ⇒ ::Object

Create a new client object for EndpointService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::EndpointService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the EndpointService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About EndpointService

A service for managing Vertex AI's Endpoints.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



97
98
99
100
101
102
103
104
105
106
# File 'lib/google/cloud/ai_platform.rb', line 97

def self.endpoint_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:EndpointService)
  service_module.const_get(:Client).new(&block)
end

.featurestore_online_serving_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeaturestoreOnlineServingService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeaturestoreOnlineServingService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeaturestoreOnlineServingService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeaturestoreOnlineServingService

A service for serving online feature values.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



127
128
129
130
131
132
133
134
135
136
# File 'lib/google/cloud/ai_platform.rb', line 127

def self.featurestore_online_serving_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeaturestoreOnlineServingService)
  service_module.const_get(:Client).new(&block)
end

.featurestore_service(version: :v1, &block) ⇒ ::Object

Create a new client object for FeaturestoreService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::FeaturestoreService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the FeaturestoreService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About FeaturestoreService

The service that handles CRUD and List for resources for Featurestore.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



157
158
159
160
161
162
163
164
165
166
# File 'lib/google/cloud/ai_platform.rb', line 157

def self.featurestore_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:FeaturestoreService)
  service_module.const_get(:Client).new(&block)
end

.index_endpoint_service(version: :v1, &block) ⇒ ::Object

Create a new client object for IndexEndpointService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::IndexEndpointService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the IndexEndpointService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About IndexEndpointService

A service for managing Vertex AI's IndexEndpoints.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



187
188
189
190
191
192
193
194
195
196
# File 'lib/google/cloud/ai_platform.rb', line 187

def self.index_endpoint_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:IndexEndpointService)
  service_module.const_get(:Client).new(&block)
end

.index_service(version: :v1, &block) ⇒ ::Object

Create a new client object for IndexService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::IndexService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the IndexService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About IndexService

A service for creating and managing Vertex AI's Index resources.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



217
218
219
220
221
222
223
224
225
226
# File 'lib/google/cloud/ai_platform.rb', line 217

def self.index_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:IndexService)
  service_module.const_get(:Client).new(&block)
end

.job_service(version: :v1, &block) ⇒ ::Object

Create a new client object for JobService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::JobService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the JobService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About JobService

A service for creating and managing Vertex AI's jobs.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



247
248
249
250
251
252
253
254
255
256
# File 'lib/google/cloud/ai_platform.rb', line 247

def self.job_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:JobService)
  service_module.const_get(:Client).new(&block)
end

.match_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MatchService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MatchService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MatchService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MatchService

MatchService is a Google managed service for efficient vector similarity search at scale.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



278
279
280
281
282
283
284
285
286
287
# File 'lib/google/cloud/ai_platform.rb', line 278

def self.match_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MatchService)
  service_module.const_get(:Client).new(&block)
end

.metadata_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MetadataService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MetadataService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MetadataService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MetadataService

Service for reading and writing metadata entries.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



308
309
310
311
312
313
314
315
316
317
# File 'lib/google/cloud/ai_platform.rb', line 308

def self. version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MetadataService)
  service_module.const_get(:Client).new(&block)
end

.migration_service(version: :v1, &block) ⇒ ::Object

Create a new client object for MigrationService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::MigrationService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the MigrationService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About MigrationService

A service that migrates resources from automl.googleapis.com, datalabeling.googleapis.com and ml.googleapis.com to Vertex AI.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



339
340
341
342
343
344
345
346
347
348
# File 'lib/google/cloud/ai_platform.rb', line 339

def self.migration_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:MigrationService)
  service_module.const_get(:Client).new(&block)
end

.model_garden_service(version: :v1, &block) ⇒ ::Object

Create a new client object for ModelGardenService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::ModelGardenService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ModelGardenService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About ModelGardenService

The interface of Model Garden Service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



399
400
401
402
403
404
405
406
407
408
# File 'lib/google/cloud/ai_platform.rb', line 399

def self.model_garden_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:ModelGardenService)
  service_module.const_get(:Client).new(&block)
end

.model_service(version: :v1, &block) ⇒ ::Object

Create a new client object for ModelService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::ModelService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ModelService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About ModelService

A service for managing Vertex AI's machine learning Models.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



369
370
371
372
373
374
375
376
377
378
# File 'lib/google/cloud/ai_platform.rb', line 369

def self.model_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:ModelService)
  service_module.const_get(:Client).new(&block)
end

.pipeline_service(version: :v1, &block) ⇒ ::Object

Create a new client object for PipelineService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::PipelineService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PipelineService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About PipelineService

A service for creating and managing Vertex AI's pipelines. This includes both TrainingPipeline resources (used for AutoML and custom training) and PipelineJob resources (used for Vertex AI Pipelines).

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



431
432
433
434
435
436
437
438
439
440
# File 'lib/google/cloud/ai_platform.rb', line 431

def self.pipeline_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:PipelineService)
  service_module.const_get(:Client).new(&block)
end

.prediction_service(version: :v1, &block) ⇒ ::Object

Create a new client object for PredictionService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::PredictionService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PredictionService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About PredictionService

A service for online predictions and explanations.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



461
462
463
464
465
466
467
468
469
470
# File 'lib/google/cloud/ai_platform.rb', line 461

def self.prediction_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:PredictionService)
  service_module.const_get(:Client).new(&block)
end

.specialist_pool_service(version: :v1, &block) ⇒ ::Object

Create a new client object for SpecialistPoolService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::SpecialistPoolService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the SpecialistPoolService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About SpecialistPoolService

A service for creating and managing Customer SpecialistPools. When customers start Data Labeling jobs, they can reuse/create Specialist Pools to bring their own Specialists to label the data. Customers can add/remove Managers for the Specialist Pool on Cloud console, then Managers will get email notifications to manage Specialists and tasks on CrowdCompute console.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



496
497
498
499
500
501
502
503
504
505
# File 'lib/google/cloud/ai_platform.rb', line 496

def self.specialist_pool_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:SpecialistPoolService)
  service_module.const_get(:Client).new(&block)
end

.tensorboard_service(version: :v1, &block) ⇒ ::Object

Create a new client object for TensorboardService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::TensorboardService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the TensorboardService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About TensorboardService

TensorboardService

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



526
527
528
529
530
531
532
533
534
535
# File 'lib/google/cloud/ai_platform.rb', line 526

def self.tensorboard_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:TensorboardService)
  service_module.const_get(:Client).new(&block)
end

.vizier_service(version: :v1, &block) ⇒ ::Object

Create a new client object for VizierService.

By default, this returns an instance of Google::Cloud::AIPlatform::V1::VizierService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the VizierService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About VizierService

Vertex AI Vizier API.

Vertex AI Vizier is a service to solve blackbox optimization problems, such as tuning machine learning hyperparameters and searching over deep learning architectures.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (::Object) —

    A client object for the specified version.



560
561
562
563
564
565
566
567
568
569
# File 'lib/google/cloud/ai_platform.rb', line 560

def self.vizier_service version: :v1, &block
  require "google/cloud/ai_platform/#{version.to_s.downcase}"

  package_name = Google::Cloud::AIPlatform
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::AIPlatform.const_get(package_name).const_get(:VizierService)
  service_module.const_get(:Client).new(&block)
end