Module: Google::Cloud::AIPlatform
- Defined in:
- lib/google/cloud/ai_platform.rb,
lib/google/cloud/ai_platform/version.rb
Constant Summary collapse
- VERSION =
"0.2.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.ai_platform| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-ai_platform library.
-
.dataset_service(version: :v1, &block) ⇒ DatasetService::Client
Create a new client object for DatasetService.
-
.endpoint_service(version: :v1, &block) ⇒ EndpointService::Client
Create a new client object for EndpointService.
-
.featurestore_online_serving_service(version: :v1, &block) ⇒ FeaturestoreOnlineServingService::Client
Create a new client object for FeaturestoreOnlineServingService.
-
.featurestore_service(version: :v1, &block) ⇒ FeaturestoreService::Client
Create a new client object for FeaturestoreService.
-
.index_endpoint_service(version: :v1, &block) ⇒ IndexEndpointService::Client
Create a new client object for IndexEndpointService.
-
.index_service(version: :v1, &block) ⇒ IndexService::Client
Create a new client object for IndexService.
-
.job_service(version: :v1, &block) ⇒ JobService::Client
Create a new client object for JobService.
-
.metadata_service(version: :v1, &block) ⇒ MetadataService::Client
Create a new client object for MetadataService.
-
.migration_service(version: :v1, &block) ⇒ MigrationService::Client
Create a new client object for MigrationService.
-
.model_service(version: :v1, &block) ⇒ ModelService::Client
Create a new client object for ModelService.
-
.pipeline_service(version: :v1, &block) ⇒ PipelineService::Client
Create a new client object for PipelineService.
-
.prediction_service(version: :v1, &block) ⇒ PredictionService::Client
Create a new client object for PredictionService.
-
.specialist_pool_service(version: :v1, &block) ⇒ SpecialistPoolService::Client
Create a new client object for SpecialistPoolService.
-
.tensorboard_service(version: :v1, &block) ⇒ TensorboardService::Client
Create a new client object for TensorboardService.
-
.vizier_service(version: :v1, &block) ⇒ VizierService::Client
Create a new client object for VizierService.
Class Method Details
.configure {|::Google::Cloud.configure.ai_platform| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-ai_platform library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
538 539 540 541 542 |
# File 'lib/google/cloud/ai_platform.rb', line 538 def self.configure yield ::Google::Cloud.configure.ai_platform if block_given? ::Google::Cloud.configure.ai_platform end |
.dataset_service(version: :v1, &block) ⇒ DatasetService::Client
Create a new client object for DatasetService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::DatasetService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the DatasetService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About DatasetService
The service that handles the CRUD of Vertex AI Dataset and its child resources.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/google/cloud/ai_platform.rb', line 67 def self.dataset_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:DatasetService).const_get(:Client).new(&block) end |
.endpoint_service(version: :v1, &block) ⇒ EndpointService::Client
Create a new client object for EndpointService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::EndpointService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the EndpointService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About EndpointService
A service for managing Vertex AI's Endpoints.
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/google/cloud/ai_platform.rb', line 97 def self.endpoint_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:EndpointService).const_get(:Client).new(&block) end |
.featurestore_online_serving_service(version: :v1, &block) ⇒ FeaturestoreOnlineServingService::Client
Create a new client object for FeaturestoreOnlineServingService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::FeaturestoreOnlineServingService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the FeaturestoreOnlineServingService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About FeaturestoreOnlineServingService
A service for serving online feature values.
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/google/cloud/ai_platform.rb', line 127 def self.featurestore_online_serving_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:FeaturestoreOnlineServingService).const_get(:Client).new(&block) end |
.featurestore_service(version: :v1, &block) ⇒ FeaturestoreService::Client
Create a new client object for FeaturestoreService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::FeaturestoreService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the FeaturestoreService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About FeaturestoreService
The service that handles CRUD and List for resources for Featurestore.
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/cloud/ai_platform.rb', line 157 def self.featurestore_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:FeaturestoreService).const_get(:Client).new(&block) end |
.index_endpoint_service(version: :v1, &block) ⇒ IndexEndpointService::Client
Create a new client object for IndexEndpointService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::IndexEndpointService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the IndexEndpointService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About IndexEndpointService
A service for managing Vertex AI's IndexEndpoints.
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/google/cloud/ai_platform.rb', line 187 def self.index_endpoint_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:IndexEndpointService).const_get(:Client).new(&block) end |
.index_service(version: :v1, &block) ⇒ IndexService::Client
Create a new client object for IndexService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::IndexService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the IndexService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About IndexService
A service for creating and managing Vertex AI's Index resources.
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/google/cloud/ai_platform.rb', line 217 def self.index_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:IndexService).const_get(:Client).new(&block) end |
.job_service(version: :v1, &block) ⇒ JobService::Client
Create a new client object for JobService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::JobService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the JobService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About JobService
A service for creating and managing Vertex AI's jobs.
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/google/cloud/ai_platform.rb', line 247 def self.job_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:JobService).const_get(:Client).new(&block) end |
.metadata_service(version: :v1, &block) ⇒ MetadataService::Client
Create a new client object for MetadataService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::MetadataService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the MetadataService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About MetadataService
Service for reading and writing metadata entries.
277 278 279 280 281 282 283 284 285 286 |
# File 'lib/google/cloud/ai_platform.rb', line 277 def self. version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:MetadataService).const_get(:Client).new(&block) end |
.migration_service(version: :v1, &block) ⇒ MigrationService::Client
Create a new client object for MigrationService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::MigrationService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the MigrationService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About MigrationService
A service that migrates resources from automl.googleapis.com, datalabeling.googleapis.com and ml.googleapis.com to Vertex AI.
308 309 310 311 312 313 314 315 316 317 |
# File 'lib/google/cloud/ai_platform.rb', line 308 def self.migration_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:MigrationService).const_get(:Client).new(&block) end |
.model_service(version: :v1, &block) ⇒ ModelService::Client
Create a new client object for ModelService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::ModelService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the ModelService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About ModelService
A service for managing Vertex AI's machine learning Models.
338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/cloud/ai_platform.rb', line 338 def self.model_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:ModelService).const_get(:Client).new(&block) end |
.pipeline_service(version: :v1, &block) ⇒ PipelineService::Client
Create a new client object for PipelineService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::PipelineService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the PipelineService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About PipelineService
A service for creating and managing Vertex AI's pipelines. This includes both
TrainingPipeline resources (used for AutoML and custom training) and
PipelineJob resources (used for Vertex AI Pipelines).
370 371 372 373 374 375 376 377 378 379 |
# File 'lib/google/cloud/ai_platform.rb', line 370 def self.pipeline_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:PipelineService).const_get(:Client).new(&block) end |
.prediction_service(version: :v1, &block) ⇒ PredictionService::Client
Create a new client object for PredictionService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::PredictionService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the PredictionService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About PredictionService
A service for online predictions and explanations.
400 401 402 403 404 405 406 407 408 409 |
# File 'lib/google/cloud/ai_platform.rb', line 400 def self.prediction_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:PredictionService).const_get(:Client).new(&block) end |
.specialist_pool_service(version: :v1, &block) ⇒ SpecialistPoolService::Client
Create a new client object for SpecialistPoolService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::SpecialistPoolService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the SpecialistPoolService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About SpecialistPoolService
A service for creating and managing Customer SpecialistPools. When customers start Data Labeling jobs, they can reuse/create Specialist Pools to bring their own Specialists to label the data. Customers can add/remove Managers for the Specialist Pool on Cloud console, then Managers will get email notifications to manage Specialists and tasks on CrowdCompute console.
435 436 437 438 439 440 441 442 443 444 |
# File 'lib/google/cloud/ai_platform.rb', line 435 def self.specialist_pool_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:SpecialistPoolService).const_get(:Client).new(&block) end |
.tensorboard_service(version: :v1, &block) ⇒ TensorboardService::Client
Create a new client object for TensorboardService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::TensorboardService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the TensorboardService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About TensorboardService
TensorboardService
465 466 467 468 469 470 471 472 473 474 |
# File 'lib/google/cloud/ai_platform.rb', line 465 def self.tensorboard_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:TensorboardService).const_get(:Client).new(&block) end |
.vizier_service(version: :v1, &block) ⇒ VizierService::Client
Create a new client object for VizierService.
By default, this returns an instance of
Google::Cloud::AIPlatform::V1::VizierService::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the VizierService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About VizierService
Vertex AI Vizier API.
Vertex AI Vizier is a service to solve blackbox optimization problems, such as tuning machine learning hyperparameters and searching over deep learning architectures.
499 500 501 502 503 504 505 506 507 508 |
# File 'lib/google/cloud/ai_platform.rb', line 499 def self.vizier_service version: :v1, &block require "google/cloud/ai_platform/#{version.to_s.downcase}" package_name = Google::Cloud::AIPlatform .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::AIPlatform.const_get package_name package_module.const_get(:VizierService).const_get(:Client).new(&block) end |